import { store } from 'https://cdn.skypack.dev/@startinblox/core@0.15';

/**
 * Initialize rai plugin.
 */
converse.plugins.add('sib-subscribe-to-rai', {
  dependencies: [
    'converse-rai',
  ],
  async initialize() {
    const _converse = this._converse;
    const { api } = _converse;

    const getCircles = new Promise((resolve, reject) => {
      const circleInterval = setInterval(async () => {
        let retry = false;
        let circles = [];
        const user = await document.querySelector('sib-auth').getUser();
        const userProfile = await store.getData(user['@id'], this.context);
        for (let circleMembership of await userProfile['circles.ldp:contains']) {
          if (circleMembership) {
            circles.push(await circleMembership['circle.jabberID']);
          } else {
            retry = true;
          }
        }
        if (!retry) {
          clearInterval(circleInterval);
          resolve(circles);
        }
      }, 250);
    });

    const getProjects = new Promise((resolve, reject) => {
      const projectInterval = setInterval(async () => {
        let retry = false;
        let projects = [];
        const user = await document.querySelector('sib-auth').getUser();
        const userProfile = await store.getData(user['@id'], this.context);
        for (let projectMembership of await userProfile['projects.ldp:contains']) {
          if (projectMembership) {
            projects.push(await projectMembership['project.jabberID']);
          } else {
            retry = true;
          }
        }
        if (!retry) {
          clearInterval(projectInterval);
          resolve(projects);
        }
      }, 250);
    });

    let userRooms = (await Promise.all([
      getCircles,
      getProjects,
    ])).flat();

    // @MattJ Here userRooms is an array of each jabberID the user is on.
    api.trigger('raiRoomsUpdated', userRooms);

    api.listen.on('chatRoomActivityIndicators', jid => {
      window.dispatchEvent(new CustomEvent('newMessage', {
        detail: {
          jid,
        },
      }));
    });
  },
});
